--[[
	----------------------------------------------------------------------------
    calca-Water

    
    Lua application for JETI DC/DS transmitters
--]]
collectgarbage()
--------------------------------------------------------------------------------
-- Locals for application
local regSwitch, testSwitch, swi, tst
local sensorLalist = { "..." }
local sensorIdlist = { "..." }
local sensorPalist = { "..." }
local waterCycle, swiEnabled, tstEnabled, actualTime = 0, true, true, 0
local ballast, inhalt, portion, change = 0,0,0,false
local dix15
--------------------------------------------------------------------------------
-- Read translations
local function setLanguage()
  local lng=system.getLocale()
  local file = io.readall("Apps/calca-Wat/calca-Wat.jsn")
  local obj = json.decode(file)
  if(obj) then
    dix15 = obj[lng] or obj[obj.default]
  end
end
--------------------------------------------------------------------------------
-- Telemetry and Data Verification
local function printTelem()
	lcd.drawText(10,20,string.format("%s", dix15.cycle),FONT_NORMAL)
	lcd.drawNumber(70,5,waterCycle,FONT_MAXI)
	lcd.drawText(10,45,string.format("Ballast: %5.4sg",ballast),FONT_NORMAL)
	collectgarbage()
end
-- Actions when settings changed
local function regSwitchChanged(value)
    local pSave = system.pSave
	regSwitch = value
	pSave("regSwitch", value)
end

local function testSwitchChanged(value)
    local pSave = system.pSave
	testSwitch = value
	pSave("testSwitch", value)
end

local function inChanged(value)
    local pSave = system.pSave
	inhalt = value
	pSave("inhalt", value)
	change = true
end

local function poChanged(value)
    local pSave = system.pSave
	portion = value
	pSave("portion", value)
end
--------------------------------------------------------------------------------
local function initForm()
        form.addLabel({label= dix15.pushB, font=FONT_MINI})
		form.addRow(2)
		form.addLabel({label= dix15.buttonWater, font=FONT_BOLD})
		form.addInputbox(regSwitch,true,regSwitchChanged, {font=FONT_BOLD})
		form.addLabel({label=dix15.pushB, font=FONT_MINI})
		form.addRow(2)
		form.addLabel({label= dix15.buttonTest, font=FONT_BOLD})
		form.addInputbox(testSwitch,true,testSwitchChanged, {font=FONT_BOLD})
		form.addLabel({label=dix15.amount, font=FONT_MINI})
		form.addRow(2)
		form.addLabel({label= dix15.total, font=FONT_BOLD})
		form.addIntbox(inhalt,0,5000,1000,0,25,inChanged, {font=FONT_BOLD})
		form.addRow(2)
		form.addLabel({label= dix15.portion, font=FONT_BOLD})
		form.addIntbox(portion,0,1000,100,0,5,poChanged, {font=FONT_BOLD})
		form.addRow(1)
		form.addLabel({label="     Powered by Swiss-Aerodesign.com   "..dix15.version.." ", font=FONT_MINI})
end
--------------------------------------------------------------------------------
local function loop()
	if change then ballast = inhalt change = false end
	local swi  = system.getInputsVal(regSwitch)
	local tst  = system.getInputsVal(testSwitch)
	if system.getTime() > (actualTime + 10) then swiEnabled = true end
	if tst and tst < 1 then tstEnabled = true end  
	if (swi and swi < 1) and (tst and tst < 1) then return end	
	if swi == 1 and swiEnabled then
	actualTime = system.getTime()
	waterCycle = waterCycle + 1
	swiEnabled = false
	ballast = ballast - portion
	if ballast < 0 then ballast = 0 end
	system.playFile("/Apps/calca-Wat/cwWater.wav", AUDIO_QUEUE)
	system.playNumber(waterCycle,0)
	end
	if tst == 1 and tstEnabled then
	tstEnabled = false
	system.playFile("/Apps/calca-Wat/cwDrop.wav", AUDIO_QUEUE)
	end	
    collectgarbage()
end
--------------------------------------------------------------------------------
local function init()
    local pLoad = system.pLoad
	regSwitch = pLoad("regSwitch")
	testSwitch = pLoad("testSwitch")
	inhalt = pLoad("inhalt",0)
	ballast = inhalt
	portion = pLoad("portion",0)
    system.registerForm(1, MENU_MAIN, dix15.appName, initForm)
	system.registerTelemetry(1, dix15.appName .. dix15.version, 2, printTelem)
    collectgarbage()
end
--------------------------------------------------------------------------------
collectgarbage()
setLanguage()
return {init=init, loop=loop, author="Walter Loetscher", version= dix15.version, name= dix15.appName}